# open this when support more pkg in the future
%bcond_with gui

Summary:   WPA/WPA2/IEEE 802.1X Supplicant
Name:      wpa_supplicant
Version:   2.11
Release:   1%{?dist}
License:   BSD
URL:       http://w1.fi/wpa_supplicant/
Source0:   http://w1.fi/releases/%{name}-%{version}.tar.gz
Source1:   wpa_supplicant.conf
Source2:   wpa_supplicant.service
Source3:   wpa_supplicant.sysconfig
Source4:   wpa_supplicant.logrotate

Patch3000: wpa_supplicant-defconfig-keep-options-we-ve-traditionally-used-enab.patch
Patch3001: wpa_supplicant-assoc-timeout.patch
Patch3002: wpa_supplicant-flush-debug-output.patch
Patch3003: wpa_supplicant-quiet-scan-results-message.patch
Patch3004: wpa_supplicant-gui-qt4.patch
Patch3006: wpa_supplicant-defconfig-keep-CONFIG_WEP-enabled.patch
Patch3007: wpa_supplicant-defconfig-enable-WPA-EAP-SUITE-B-192-ciphers.patch
Patch3008: wpa_supplicant-defconfig-enable-OCV-support.patch
Patch3009: wpa_supplicant-allow-legacy-renegotiation.patch
# Patch3010: wpa_supplicant-fix-CVE-2024-5290.patch

%if %{with gui}
BuildRequires: qt-devel
%endif
BuildRequires: openssl-devel readline-devel dbus-devel libnl3-devel
BuildRequires: systemd-units docbook-utils gcc
Requires(post): systemd-sysv
%{?systemd_requires}

%description
This package provides a WPA Supplicant for Linux, BSD and Windows
with support for WPA and WPA2 (IEEE 802.11i / RSN). Supplicant is
the IEEE 802.1X/WPA component that is used in the client stations.
It implements key negotiation with a WPA Authenticator and it
controls the roaming and IEEE 802.11 authentication/association of
the wlan driver.

%if %{with gui}
%package gui
Summary: Graphical User Interface for %{name}

%description gui
Graphical User Interface for wpa_supplicant written using QT
%endif

%prep
%autosetup -p1 -n %{name}-%{version}

%build
pushd wpa_supplicant
  cp defconfig .config
  export CFLAGS="${CFLAGS:-%optflags} -fPIE -DPIE"
  export CXXFLAGS="${CXXFLAGS:-%optflags} -fPIE -DPIE"
  export LDFLAGS="${LDFLAGS:-%optflags} -pie -Wl,-z,now"
  export BINDIR="%{_sbindir}"
  export LIBDIR="%{_libdir}"
  %make_build
%if %{with gui}
  make wpa_gui-qt4 %{_smp_mflags} V=1 QTDIR=%{_libdir}/qt4 \
    QMAKE='%{qmake_qt4}' LRELEASE='%{_qt4_bindir}/lrelease'
%endif
  make eapol_test V=1
  make -C doc/docbook man V=1
%if !%with gui
  rm doc/docbook/wpa_gui.8
%endif
popd


%install
install -D -m 0600 %{SOURCE1} %{buildroot}/%{_sysconfdir}/wpa_supplicant/wpa_supplicant.conf
install -D -m 0644 %{SOURCE2} %{buildroot}/%{_unitdir}/wpa_supplicant.service
install -D -m 0644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/sysconfig/wpa_supplicant
install -D -m 0644 %{SOURCE4} %{buildroot}/%{_sysconfdir}/logrotate.d/wpa_supplicant
install -d %{buildroot}/%{_sbindir}
install -m 0755 wpa_supplicant/wpa_passphrase %{buildroot}/%{_sbindir}
install -m 0755 wpa_supplicant/wpa_cli %{buildroot}/%{_sbindir}
install -m 0755 wpa_supplicant/wpa_supplicant %{buildroot}/%{_sbindir}
install -m 0755 wpa_supplicant/eapol_test %{buildroot}/%{_sbindir}
install -D -m 0644 wpa_supplicant/dbus/dbus-wpa_supplicant.conf \
  %{buildroot}/%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
install -D -m 0644 wpa_supplicant/dbus/fi.w1.wpa_supplicant1.service \
  %{buildroot}/%{_datadir}/dbus-1/system-services/fi.w1.wpa_supplicant1.service

%if %{with gui}
install -d %{buildroot}/%{_bindir}
install -m 0755 wpa_supplicant/wpa_gui-qt4/wpa_gui %{buildroot}/%{_bindir}
%endif

install -d %{buildroot}%{_mandir}/man{5,8}
install -m 0644 wpa_supplicant/doc/docbook/*.8 %{buildroot}%{_mandir}/man8
install -m 0644 wpa_supplicant/doc/docbook/*.5 %{buildroot}%{_mandir}/man5

rm -f  wpa_supplicant/doc/.cvsignore
rm -rf wpa_supplicant/doc/docbook
chmod -R 0644 wpa_supplicant/examples/*.py

%post
%systemd_post wpa_supplicant.service

%preun
%systemd_preun wpa_supplicant.service

%files
%license COPYING
%doc README
%doc wpa_supplicant/ChangeLog
%doc wpa_supplicant/eap_testing.txt
%doc wpa_supplicant/todo.txt
%doc wpa_supplicant/wpa_supplicant.conf
%doc wpa_supplicant/examples
%config(noreplace) %{_sysconfdir}/wpa_supplicant/wpa_supplicant.conf
%config(noreplace) %{_sysconfdir}/sysconfig/wpa_supplicant
%dir %{_sysconfdir}/logrotate.d
%config(noreplace) %{_sysconfdir}/logrotate.d/wpa_supplicant
%{_unitdir}/wpa_supplicant.service
%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
%{_datadir}/dbus-1/system-services/fi.w1.wpa_supplicant1.service
%{_sbindir}/wpa_passphrase
%{_sbindir}/wpa_supplicant
%{_sbindir}/wpa_cli
%{_sbindir}/eapol_test
%dir %{_sysconfdir}/wpa_supplicant
%{_mandir}/man8/*.8.gz
%{_mandir}/man5/*
%if %{with gui}
%exclude %{_mandir}/man8/wpa_gui.8.gz

%files gui
%{_bindir}/wpa_gui
%{_mandir}/man8/wpa_gui.8.gz
%endif


%changelog
* Tue Feb 18 2025 xiaoyunzhao <xiaoyunzhao@opencloudos.tech> - 2.11-1
- [Type] bugfix
- [DESC] upgrade to 2.11 to fix CVE-2023-52424

* Mon Nov 25 2024 xiaoyunzhao <xiaoyunzhao@uniontech.com> - 2.10-7
- Fix CVE-2024-5290

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.10-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.10-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.10-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.10-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.10-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Nov 18 2022 Shuo Wang <abushwang@tencent.com> - 2.10-1
- initial build

